@@ -17,6 +17,8 @@
    Boston, MA 02110-1301, USA.
 */
 
+#define QT_NO_CAST_FROM_ASCII
+
 #include "kio_trash.h"
 #include <kio/job.h>
 
@@ -28,7 +30,6 @@
 
 #include <QCoreApplication>
 #include <QDataStream>
-#include <QTextStream>
 #include <QFile>
 #include <QEventLoop>
 
@@ -121,7 +122,7 @@ void TrashProtocol::rename( const KUrl &oldURL, const KUrl &newURL, KIO::JobFlag
 
     kDebug()<<"TrashProtocol::rename(): old="<<oldURL<<" new="<<newURL<<" overwrite=" << (flags & KIO::Overwrite);
 
-    if ( oldURL.protocol() == "trash" && newURL.protocol() == "trash" ) {
+    if (oldURL.protocol() == QLatin1String("trash") && newURL.protocol() == QLatin1String("trash")) {
         error( KIO::ERR_CANNOT_RENAME, oldURL.prettyUrl() );
         return;
     }
@@ -135,7 +136,7 @@ void TrashProtocol::copy( const KUrl &src, const KUrl &dest, int /*permissions*/
 
     kDebug()<<"TrashProtocol::copy(): " << src << " " << dest;
 
-    if ( src.protocol() == "trash" && dest.protocol() == "trash" ) {
+    if (src.protocol() == QLatin1String("trash") && dest.protocol() == QLatin1String("trash")) {
         error( KIO::ERR_UNSUPPORTED_ACTION, i18n( "This file is already in the trash bin." ) );
         return;
     }
@@ -145,7 +146,7 @@ void TrashProtocol::copy( const KUrl &src, const KUrl &dest, int /*permissions*/
 
 void TrashProtocol::copyOrMove( const KUrl &src, const KUrl &dest, bool overwrite, CopyOrMove action )
 {
-    if ( src.protocol() == "trash" && dest.isLocalFile() ) {
+    if (src.protocol() == QLatin1String("trash") && dest.isLocalFile()) {
         // Extracting (e.g. via dnd). Ignore original location stored in info file.
         int trashId;
         QString fileId, relativePath;
@@ -180,7 +181,7 @@ void TrashProtocol::copyOrMove( const KUrl &src, const KUrl &dest, bool overwrit
             finished();
         }
         return;
-    } else if ( src.isLocalFile() && dest.protocol() == "trash" ) {
+    } else if (src.isLocalFile() && dest.protocol() == QLatin1String("trash")) {
         QString dir = dest.directory();
         //kDebug() << "trashing a file to " << dir;
         // Trashing a file
@@ -212,7 +213,7 @@ void TrashProtocol::copyOrMove( const KUrl &src, const KUrl &dest, bool overwrit
                 } else {
                     // Inform caller of the final URL. Used by konq_undo.
                     const KUrl url = impl.makeURL( trashId, fileId, QString() );
-                    setMetaData( "trashURL-" + srcPath, url.url() );
+                    setMetaData(QString::fromLatin1("trashURL-") + srcPath, url.url());
                     finished();
                 }
             }
@@ -223,8 +224,9 @@ void TrashProtocol::copyOrMove( const KUrl &src, const KUrl &dest, bool overwrit
             error( KIO::ERR_ACCESS_DENIED, dest.prettyUrl() );
             return;
         }
-    } else
-        error( KIO::ERR_UNSUPPORTED_ACTION, "should never happen" );
+    } else {
+        error(KIO::ERR_UNSUPPORTED_ACTION, i18n("Internal error in copyOrMove, should never happen"));
+    }
 }
 
 void TrashProtocol::createTopLevelDirEntry(KIO::UDSEntry& entry)
@@ -242,7 +244,7 @@ void TrashProtocol::stat(const KUrl& url)
 {
     INIT_IMPL;
     const QString path = url.path();
-    if( path.isEmpty() || path == "/" ) {
+    if (path.isEmpty() || path == QLatin1String("/")) {
         // The root is "virtual" - it's not a single physical directory
         KIO::UDSEntry entry;
         createTopLevelDirEntry( entry );
@@ -264,13 +266,15 @@ void TrashProtocol::stat(const KUrl& url)
             return;
         }
 
+        kDebug() << "parsed" << url << "got" << trashId << fileId << relativePath;
+
         const QString filePath = impl.physicalPath( trashId, fileId, relativePath );
         if ( filePath.isEmpty() ) {
             error( impl.lastErrorCode(), impl.lastErrorMessage() );
             return;
         }
 
-        QString fileName = filePath.section('/', -1, -1, QString::SectionSkipEmpty);
+        QString fileName = filePath.section(QLatin1Char('/'), -1, -1, QString::SectionSkipEmpty);
 
         KUrl fileURL;
         if ( url.path().length() > 1 ) {
@@ -294,6 +298,7 @@ void TrashProtocol::stat(const KUrl& url)
 
 void TrashProtocol::del( const KUrl &url, bool /*isfile*/ )
 {
+    INIT_IMPL;
     int trashId;
     QString fileId, relativePath;
 
@@ -345,7 +350,7 @@ void TrashProtocol::listDir(const KUrl& url)
         return;
     }
     if ( !relativePath.isEmpty() ) {
-        info.physicalPath += '/';
+        info.physicalPath += QLatin1Char('/');
         info.physicalPath += relativePath;
     }
 
@@ -358,14 +363,14 @@ void TrashProtocol::listDir(const KUrl& url)
           entryIt != entryEnd ; ++entryIt )
     {
         const QString fileName = *entryIt;
-        if ( fileName == ".." )
+        if (fileName == QLatin1String(".."))
             continue;
-        const QString filePath = info.physicalPath + '/' + fileName;
+        const QString filePath = info.physicalPath + QLatin1Char('/') + fileName;
         // shouldn't be necessary
         //const QString url = TrashImpl::makeURL( trashId, fileId, relativePath + '/' + fileName );
         entry.clear();
         TrashedFileInfo infoForItem( info );
-        infoForItem.origPath += '/';
+        infoForItem.origPath += QLatin1Char('/');
         infoForItem.origPath += fileName;
         if ( ok && createUDSEntry( filePath, fileName, fileName, entry, infoForItem ) ) {
             listEntry( entry, false );
@@ -425,7 +430,7 @@ bool TrashProtocol::createUDSEntry( const QString& physicalPath, const QString&
     entry.insert( KIO::UDSEntry::UDS_MODIFICATION_TIME, buff.st_mtime );
     entry.insert( KIO::UDSEntry::UDS_ACCESS_TIME, buff.st_atime ); // ## or use it for deletion time?
     entry.insert( KIO::UDSEntry::UDS_EXTRA, info.origPath );
-    entry.insert( KIO::UDSEntry::UDS_EXTRA, info.deletionDate.toString( Qt::ISODate ) );
+    entry.insert( KIO::UDSEntry::UDS_EXTRA + 1, info.deletionDate.toString( Qt::ISODate ) );
     return true;
 }
 
