@@ -1,5 +1,5 @@
 /* This file is part of the KDE Project
-   Copyright (c) 2007-2008 Sebastian Trueg <trueg@kde.org>
+   Copyright (c) 2007-2010 Sebastian Trueg <trueg@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -31,6 +31,8 @@ namespace Soprano {
     }
 }
 
+class KInotify;
+
 class KUrl;
 
 namespace Nepomuk {
@@ -46,16 +48,33 @@ namespace Nepomuk {
         FileWatch( QObject* parent, const QVariantList& );
         ~FileWatch();
 
+        /**
+         * Tells strigi to update the folder at \p path or the folder
+         * containing \p path in case it is a file.
+         */
+        static void updateFolderViaStrigi( const QString& path );
+
     public Q_SLOTS:
-        Q_SCRIPTABLE void moveFileMetadata( const QString& from, const QString& to );
+        Q_SCRIPTABLE void watchFolder( const QString& path );
 
     private Q_SLOTS:
         void slotFileMoved( const QString& from, const QString& to );
         void slotFileDeleted( const QString& path );
         void slotFilesDeleted( const QStringList& path );
+        void slotFileCreated( const QString& );
+        void slotFileModified( const QString& );
+        void slotMovedWithoutData( const QString& );
+        void connectToKDirWatch();
+#ifdef BUILD_KINOTIFY
+        void slotInotifyWatchUserLimitReached();
+#endif
 
     private:
         MetadataMover* m_metadataMover;
+
+#ifdef BUILD_KINOTIFY
+        KInotify* m_dirWatch;
+#endif
     };
 }
 
