@@ -53,7 +53,9 @@ Nepomuk::Repository::Repository( const QString& name )
     : m_name( name ),
       m_state( CLOSED ),
       m_model( 0 ),
-      m_modelCopyJob( 0 )
+      m_backend( 0 ),
+      m_modelCopyJob( 0 ),
+      m_oldStorageBackend( 0 )
 {
 }
 
@@ -204,7 +206,6 @@ void Nepomuk::Repository::open()
                 kDebug() << "Starting model conversion";
 
                 convertingData = true;
-                // No need to use the index filter as it already contains the data
                 m_modelCopyJob = new ModelCopyJob( oldModel, m_model, this );
                 connect( m_modelCopyJob, SIGNAL( result( KJob* ) ), this, SLOT( copyFinished( KJob* ) ) );
                 m_modelCopyJob->start();
