@@ -1,5 +1,5 @@
 /* This file is part of the KDE Project
-   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>
+   Copyright (c) 2008-2010 Sebastian Trueg <trueg@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,16 +28,16 @@
 #include <vector>
 #include <string>
 
+#include <KUrl>
+
 namespace Strigi {
     class StreamAnalyzer;
     class IndexManager;
 }
 
 class QFileInfo;
-class QUrl;
-class KUrl;
 class QByteArray;
-
+class QTimer;
 
 namespace Nepomuk {
     /**
@@ -64,6 +64,14 @@ namespace Nepomuk {
          */
         QString currentFolder() const;
 
+        /**
+         * The file currently being indexed. Empty if not indexing.
+         * If suspended the file might still be set!
+         *
+         * This file should always be a child of currentFolder().
+         */
+        QString currentFile() const;
+
         enum UpdateDirFlag {
             /**
              * No flags, only used to make code more readable
@@ -148,6 +156,11 @@ namespace Nepomuk {
          */
         void updateAll( bool forceUpdate = false );
 
+        /**
+         * Analyze the one file without conditions.
+         */
+        void analyzeFile( const QString& path );
+
         /**
          * Analyze a resource that is not read from the local harddisk.
          *
@@ -165,21 +178,22 @@ namespace Nepomuk {
         void indexingSuspended( bool suspended );
 
     private Q_SLOTS:
-        void readConfig();
         void slotConfigChanged();
+        void slotDirsToUpdateWakeupTimeout();
 
     private:
         void run();
 
-        bool waitForContinue();
+        bool waitForContinue( bool disableDelay = false );
         bool updateDir( const QString& dir, Strigi::StreamAnalyzer* analyzer, UpdateDirFlags flags );
         void analyzeFile( const QFileInfo& file, Strigi::StreamAnalyzer* analyzer );
+        void queueAllFoldersForUpdate( bool forceUpdate = false );
 
         /**
          * Deletes all indexed information about entries and all subfolders and files
          * from the store
          */
-        void deleteEntries( const std::vector<std::string>& entries );
+        void deleteEntries( const QStringList& entries );
 
         // emits indexingStarted or indexingStopped based on parameter. Makes sure
         // no signal is emitted twice
@@ -207,8 +221,10 @@ namespace Nepomuk {
 
         QMutex m_dirsToUpdateMutex;
         QWaitCondition m_dirsToUpdateWc;
+        QTimer* m_dirsToUpdateWakeupTimer;
 
         QString m_currentFolder;
+        KUrl m_currentUrl;
 
         IndexingSpeed m_speed;
     };
