@@ -24,11 +24,11 @@
 #include "systray.h"
 #include "strigiserviceconfig.h"
 #include "statuswidget.h"
-#include "filesystemwatcher.h"
-#include "useractivitymonitor.h"
+#include "filewatchserviceinterface.h"
 
 #include <KDebug>
 #include <KDirNotify>
+#include <KIdleTime>
 
 #include <strigi/indexpluginloader.h>
 #include <strigi/indexmanager.h>
@@ -42,10 +42,6 @@ Nepomuk::StrigiService::StrigiService( QObject* parent, const QList<QVariant>& )
     : Service( parent, true ),
       m_indexManager( 0 )
 {
-    // only so ResourceManager won't open yet another connection to the nepomuk server
-    ResourceManager::instance()->setOverrideMainModel( mainModel() );
-
-
     // lower process priority - we do not want to spoil KDE usage
     // ==============================================================
     if ( !lowerPriority() )
@@ -64,18 +60,6 @@ Nepomuk::StrigiService::StrigiService( QObject* parent, const QList<QVariant>& )
         // monitor all kinds of events
         ( void )new EventMonitor( m_indexScheduler, this );
 
-        // monitor the file system
-        m_fsWatcher = new FileSystemWatcher( this );
-        m_fsWatcher->setWatchRecursively( true );
-        connect( m_fsWatcher, SIGNAL( dirty( QString ) ),
-                 this, SLOT( slotDirDirty( QString ) ) );
-
-        // monitor all KDE-ish changes for quick updates
-        connect( new org::kde::KDirNotify( QString(), QString(), QDBusConnection::sessionBus(), this ),
-                 SIGNAL( FilesAdded( QString ) ),
-                 this, SLOT( slotDirDirty( const QString& ) ) );
-
-
         // update the watches if the config changes
         connect( StrigiServiceConfig::self(), SIGNAL( configChanged() ),
                  this, SLOT( updateWatches() ) );
@@ -98,22 +82,13 @@ Nepomuk::StrigiService::StrigiService( QObject* parent, const QList<QVariant>& )
                  this, SIGNAL( statusStringChanged() ) );
         connect( m_indexScheduler, SIGNAL( indexingSuspended(bool) ),
                  this, SIGNAL( statusStringChanged() ) );
-        connect( m_fsWatcher, SIGNAL( statusChanged(FileSystemWatcher::Status) ),
-                 this, SIGNAL( statusStringChanged() ) );
 
         // setup the indexer to index at snail speed for the first two minutes
         // this is done for KDE startup - to not slow that down too much
         m_indexScheduler->setIndexingSpeed( IndexScheduler::SnailPace );
-        QTimer::singleShot( 2*60*1000, m_indexScheduler, SLOT( setReducedIndexingSpeed() ) );
 
-        // slow down on user activity (start also only after 2 minutes)
-        UserActivityMonitor* userActivityMonitor = new UserActivityMonitor( this );
-        connect( userActivityMonitor, SIGNAL( userActive( bool ) ),
-                 m_indexScheduler, SLOT( setReducedIndexingSpeed( bool ) ) );
-        QTimer::singleShot( 2*60*1000, userActivityMonitor, SLOT( start() ) );
-
-        // start watching the index folders
-        QTimer::singleShot( 2*60*1000, this, SLOT( updateWatches() ) );
+        // delayed init for the rest which uses IO and CPU
+        QTimer::singleShot( 2*60*1000, this, SLOT( finishInitialization() ) );
 
         // start the actual indexing
         m_indexScheduler->start();
@@ -139,46 +114,80 @@ Nepomuk::StrigiService::~StrigiService()
 }
 
 
-void Nepomuk::StrigiService::updateWatches()
+void Nepomuk::StrigiService::finishInitialization()
 {
-    // the hard way since the KDirWatch API is too simple
-    QStringList folders = StrigiServiceConfig::self()->folders();
-    if ( folders != m_fsWatcher->folders() ) {
-        m_fsWatcher->setFolders( StrigiServiceConfig::self()->folders() );
-        m_fsWatcher->setInterval( 2*60 ); // check every 2 minutes
-        m_fsWatcher->start();
-    }
+    // slow down on user activity (start also only after 2 minutes)
+    KIdleTime* idleTime = KIdleTime::instance();
+    idleTime->addIdleTimeout( 1000 * 60 * 2 ); // 2 min
+
+    connect( idleTime, SIGNAL(timeoutReached(int)), this, SLOT(slotIdleTimeoutReached()) );
+    connect( idleTime, SIGNAL(resumingFromIdle()), this, SLOT(slotIdleTimerResume()) );
+
+    // start out with reduced speed until the user is idle for 2 min
+    m_indexScheduler->setIndexingSpeed( IndexScheduler::ReducedSpeed );
+
+    updateWatches();
+}
+
+void Nepomuk::StrigiService::slotIdleTimeoutReached()
+{
+    m_indexScheduler->setIndexingSpeed( IndexScheduler::FullSpeed );
+    KIdleTime::instance()->catchNextResumeEvent();
+}
+
+void Nepomuk::StrigiService::slotIdleTimerResume()
+{
+    m_indexScheduler->setIndexingSpeed( IndexScheduler::ReducedSpeed );
 }
 
 
-void Nepomuk::StrigiService::slotDirDirty( const QString& path )
+void Nepomuk::StrigiService::updateWatches()
 {
-    if ( StrigiServiceConfig::self()->shouldFolderBeIndexed( path ) ) {
-        m_indexScheduler->updateDir( path );
+    org::kde::nepomuk::FileWatch filewatch( "org.kde.nepomuk.services.nepomukfilewatch",
+                                            "/nepomukfilewatch",
+                                            QDBusConnection::sessionBus() );
+    foreach( const QString& folder, StrigiServiceConfig::self()->includeFolders() ) {
+        filewatch.watchFolder( folder );
     }
 }
 
 
 QString Nepomuk::StrigiService::userStatusString() const
+{
+    return userStatusString( false );
+}
+
+
+QString Nepomuk::StrigiService::simpleUserStatusString() const
+{
+    return userStatusString( true );
+}
+
+
+QString Nepomuk::StrigiService::userStatusString( bool simple ) const
 {
     bool indexing = m_indexScheduler->isIndexing();
     bool suspended = m_indexScheduler->isSuspended();
     QString folder = m_indexScheduler->currentFolder();
 
-    if ( suspended )
+    if ( suspended ) {
         return i18nc( "@info:status", "File indexer is suspended" );
-    else if ( indexing )
-        return i18nc( "@info:status", "Strigi is currently indexing files in folder %1", folder );
-    else if ( m_fsWatcher->status() == FileSystemWatcher::Checking )
-        return i18nc( "@info:status", "Checking file system for new files" );
-    else
+    }
+    else if ( indexing ) {
+        if ( folder.isEmpty() || simple )
+            return i18nc( "@info:status", "Strigi is currently indexing files" );
+        else
+            return i18nc( "@info:status", "Strigi is currently indexing files in folder %1", folder );
+    }
+    else {
         return i18nc( "@info:status", "File indexer is idle" );
+    }
 }
 
 
 bool Nepomuk::StrigiService::isIdle() const
 {
-    return ( !m_indexScheduler->isIndexing() && m_fsWatcher->status() == FileSystemWatcher::Idle );
+    return ( !m_indexScheduler->isIndexing() );
 }
 
 
@@ -186,11 +195,9 @@ void Nepomuk::StrigiService::setSuspended( bool suspend )
 {
     if ( suspend ) {
         m_indexScheduler->suspend();
-        m_fsWatcher->suspend();
     }
     else {
         m_indexScheduler->resume();
-        m_fsWatcher->resume();
     }
 }
 
