@@ -42,6 +42,8 @@ Q_DECLARE_METATYPE(Plasma::Animation*)
 Q_DECLARE_METATYPE(Plasma::Applet*)
 Q_DECLARE_METATYPE(Plasma::Extender*)
 Q_DECLARE_METATYPE(Plasma::VideoWidget::Controls)
+Q_DECLARE_METATYPE(Plasma::Svg*)
+Q_DECLARE_METATYPE(Qt::MouseButton)
 
 Q_DECLARE_METATYPE(AppletInterface*)
 
@@ -167,12 +169,24 @@ QScriptValue qScriptValueFromQGraphicsWidget(QScriptEngine *engine, const QGraph
     return engine->newQObject(const_cast<QGraphicsWidget *>(anim), QScriptEngine::AutoOwnership, QScriptEngine::PreferExistingWrapperObject);
 }
 
-void qGraphicsWidgetFromQScriptValue(const QScriptValue &scriptValue, QGraphicsWidgetPtr &anim)
+void graphicsWidgetFromQScriptValue(const QScriptValue &scriptValue, QGraphicsWidgetPtr &anim)
 {
     QObject *obj = scriptValue.toQObject();
     anim = static_cast<QGraphicsWidget *>(obj);
 }
 
+typedef Plasma::Svg * SvgPtr;
+QScriptValue qScriptValueFromSvg(QScriptEngine *engine, const SvgPtr &anim)
+{
+    return engine->newQObject(const_cast<Plasma::Svg *>(anim), QScriptEngine::AutoOwnership, QScriptEngine::PreferExistingWrapperObject);
+}
+
+void svgFromQScriptValue(const QScriptValue &scriptValue, SvgPtr &anim)
+{
+    QObject *obj = scriptValue.toQObject();
+    anim = static_cast<Plasma::Svg *>(obj);
+}
+
 typedef Plasma::Extender *ExtenderPtr;
 QScriptValue qScriptValueFromExtender(QScriptEngine *engine, const ExtenderPtr &extender)
 {
@@ -185,57 +199,31 @@ void extenderFromQScriptValue(const QScriptValue &scriptValue, ExtenderPtr &exte
     extender = static_cast<Plasma::Extender *>(obj);
 }
 
-typedef Plasma::Service *ServicePtr;
-QScriptValue qScriptValueFromService(QScriptEngine *engine, const ServicePtr &service)
+QScriptValue qScriptValueFromMouseButton(QScriptEngine *, const Qt::MouseButton &button)
 {
-    return engine->newQObject(const_cast<Plasma::Service *>(service), QScriptEngine::AutoOwnership, QScriptEngine::PreferExistingWrapperObject);
+    return int(button);
 }
 
-void serviceFromQScriptValue(const QScriptValue &scriptValue, ServicePtr &service)
+void mouseButtonFromScriptValue(const QScriptValue &scriptValue, Qt::MouseButton &button)
 {
-    QObject *obj = scriptValue.toQObject();
-    service = static_cast<Plasma::Service *>(obj);
+    button = static_cast<Qt::MouseButton>(scriptValue.toInt32());
 }
 
-typedef Plasma::DataEngine *DataEnginePtr;
-QScriptValue qScriptValueFromDataEngine(QScriptEngine *engine, const DataEnginePtr &dataEngine)
-{
-    return engine->newQObject(const_cast<Plasma::DataEngine *>(dataEngine), QScriptEngine::AutoOwnership, QScriptEngine::PreferExistingWrapperObject);
-}
-
-void dataEngineFromQScriptValue(const QScriptValue &scriptValue, DataEnginePtr &dataEngine)
-{
-    QObject *obj = scriptValue.toQObject();
-    dataEngine = static_cast<Plasma::DataEngine *>(obj);
-}
-
-typedef Plasma::ServiceJob *ServiceJobPtr;
-QScriptValue qScriptValueFromServiceJob(QScriptEngine *engine, const ServiceJobPtr &serviceJob)
-{
-    return engine->newQObject(const_cast<Plasma::ServiceJob *>(serviceJob), QScriptEngine::AutoOwnership, QScriptEngine::PreferExistingWrapperObject);
-}
-
-void serviceJobFromQScriptValue(const QScriptValue &scriptValue, ServiceJobPtr &serviceJob)
-{
-    QObject *obj = scriptValue.toQObject();
-    serviceJob = static_cast<Plasma::ServiceJob *>(obj);
-}
+using namespace Plasma;
 
 void registerSimpleAppletMetaTypes(QScriptEngine *engine)
 {
-    qScriptRegisterMetaType<QGraphicsWidget*>(engine, qScriptValueFromQGraphicsWidget, qGraphicsWidgetFromQScriptValue);
+    qScriptRegisterMetaType<QGraphicsWidget*>(engine, qScriptValueFromQGraphicsWidget, graphicsWidgetFromQScriptValue);
+    qScriptRegisterMetaType<Plasma::Svg*>(engine, qScriptValueFromSvg, svgFromQScriptValue);
 
     qScriptRegisterMetaType<KConfigGroup>(engine, qScriptValueFromKConfigGroup, kConfigGroupFromScriptValue, QScriptValue());
     qScriptRegisterMetaType<KJob *>(engine, qScriptValueFromKJob, qKJobFromQScriptValue);
     qScriptRegisterMetaType<KIO::Job *>(engine, qScriptValueFromKIOJob, qKIOJobFromQScriptValue);
 
     qScriptRegisterMetaType<Plasma::Animation *>(engine, qScriptValueFromAnimation, abstractAnimationFromQScriptValue);
-    qScriptRegisterMetaType<Plasma::Extender *>(engine, qScriptValueFromExtender , extenderFromQScriptValue);
+    qScriptRegisterMetaType<Plasma::Extender *>(engine, qScriptValueFromExtender, extenderFromQScriptValue);
     qScriptRegisterMetaType<Plasma::VideoWidget::Controls>(engine, qScriptValueFromControls, controlsFromScriptValue, QScriptValue());
-    qRegisterMetaType<DataEngine::Data>("Plasma::DataEngine::Data");
-    qRegisterMetaType<DataEngine::Data>("DataEngine::Data");
-    qScriptRegisterMapMetaType<DataEngine::Data>(engine);
-    qScriptRegisterMetaType<Plasma::Service *>(engine, qScriptValueFromService, serviceFromQScriptValue);
-    qScriptRegisterMetaType<Plasma::DataEngine *>(engine, qScriptValueFromDataEngine, dataEngineFromQScriptValue);
-    qScriptRegisterMetaType<Plasma::ServiceJob *>(engine, qScriptValueFromServiceJob, serviceJobFromQScriptValue);
+    qScriptRegisterMetaType<Qt::MouseButton>(engine, qScriptValueFromMouseButton, mouseButtonFromScriptValue);
+    registerDataEngineMetaTypes(engine);
 }
+
